@@ -1,6 +1,6 @@
 /**
 *******************************************************************************
-* Copyright (C) 1996-2006, International Business Machines Corporation and    *
+* Copyright (C) 1996-2007, International Business Machines Corporation and    *
 * others. All Rights Reserved.                                                *
 *******************************************************************************
 */
@@ -13,9 +13,7 @@ import java.util.Set;
 
 import com.ibm.icu.impl.ICUDebug;
 import com.ibm.icu.impl.ICUResourceBundle;
-import com.ibm.icu.impl.LocaleUtility;
 import com.ibm.icu.util.ULocale;
-import com.ibm.icu.util.UResourceBundle;
 import com.ibm.icu.util.VersionInfo;
 
 /**
@@ -25,7 +23,7 @@ import com.ibm.icu.util.VersionInfo;
 *
 * <p>Following the <a href=http://www.unicode.org>Unicode
 * Consortium</a>'s specifications for the
-* <a href="http://www.unicode.org/unicode/reports/tr10/"> Unicode Collation
+* <a href="http://www.unicode.org/unicode/reports/tr10/">Unicode Collation
 * Algorithm (UCA)</a>, there are 5 different levels of strength used
 * in comparisons:
 *
@@ -48,7 +46,7 @@ import com.ibm.icu.util.VersionInfo;
 *     difference between large and small Kana. A tertiary difference is ignored
 *     when there is a primary or secondary difference anywhere in the strings.
 * <li>QUATERNARY strength: When punctuation is ignored
-*     <a href="http://icu.sourceforge.net/userguide/Collate_Concepts.html#Ignoring_Punctuation">
+*     <a href="http://www.icu-project.org/userguide/Collate_Concepts.html#Ignoring_Punctuation">
 *     (see Ignoring Punctuations in the user guide)</a> at PRIMARY to TERTIARY
 *     strength, an additional strength level can
 *     be used to distinguish words with and without punctuation (for example,
@@ -79,7 +77,7 @@ import com.ibm.icu.util.VersionInfo;
 * a comparison or before getting a CollationKey.</p>
 *
 * <p>For more information about the collation service see the
-* <a href="http://icu.sourceforge.net/userguide/Collate_Intro.html">users
+* <a href="http://www.icu-project.org/userguide/Collate_Intro.html">users
 * guide</a>.</p>
 *
 * <p>Examples of use
@@ -157,7 +155,7 @@ public abstract class Collator implements Comparator, Cloneable
     /**
      * Fourth level collator strength value.
      * When punctuation is ignored
-     * <a href="http://icu.sourceforge.net/userguide/Collate_Concepts.html#Ignoring_Punctuation">
+     * <a href="http://www.icu-project.org/userguide/Collate_Concepts.html#Ignoring_Punctuation">
      * (see Ignoring Punctuations in the user guide)</a> at PRIMARY to TERTIARY
      * strength, an additional strength level can
      * be used to distinguish words with and without punctuation.
@@ -187,8 +185,7 @@ public abstract class Collator implements Comparator, Cloneable
      * This is for backwards compatibility with Java APIs only.  It
      * should not be used, IDENTICAL should be used instead.  ICU's
      * collation does not support Java's FULL_DECOMPOSITION mode.
-     * @draft ICU 3.4
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.4
      */
     public final static int FULL_DECOMPOSITION = IDENTICAL;
 
@@ -357,8 +354,7 @@ public abstract class Collator implements Comparator, Cloneable
          * this method instead of createCollator(Locale).
          * @param loc the locale for which this collator is to be created.
          * @return the newly created collator.
-         * @draft ICU 3.2
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 3.2
          */
         public Collator createCollator(ULocale loc) {
             return createCollator(loc.toLocale());
@@ -397,8 +393,7 @@ public abstract class Collator implements Comparator, Cloneable
          * @param objectLocale the locale identifying the collator
          * @param displayLocale the locale for which the display name of the collator should be localized
          * @return the display name
-         * @draft ICU 3.2
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 3.2
          */
         public String getDisplayName(ULocale objectLocale, ULocale displayLocale) {
             if (visible()) {
@@ -476,8 +471,7 @@ public abstract class Collator implements Comparator, Cloneable
      * @see java.util.ResourceBundle
      * @see #getInstance(Locale)
      * @see #getInstance()
-     * @draft ICU 3.0
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.0
      */
     public static final Collator getInstance(ULocale locale) {
         // fetching from service cache is faster than instantiation
@@ -509,8 +503,7 @@ public abstract class Collator implements Comparator, Cloneable
      * @param locale the locale for which this is the default collator
      * @return an object that can be used to unregister the registered collator.
      *
-     * @draft ICU 3.2
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.2
      */
     public static final Object registerInstance(Collator collator, ULocale locale) {
         return getShim().registerInstance(collator, locale);
@@ -563,8 +556,7 @@ public abstract class Collator implements Comparator, Cloneable
      * @return the list of locales in which collators are installed.
      * This list includes any that have been registered, in addition to
      * those that are installed with ICU4J.
-     * @draft ICU 3.0
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.0
      */
     public static final ULocale[] getAvailableULocales() {
         if (shim == null) {
@@ -599,8 +591,7 @@ public abstract class Collator implements Comparator, Cloneable
      * service is "collation".
      * @return an array of valid collation keywords.
      * @see #getKeywordValues
-     * @draft ICU 3.0
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.0
      */
     public static final String[] getKeywords() {
         return KEYWORDS;
@@ -611,8 +602,7 @@ public abstract class Collator implements Comparator, Cloneable
      * that keyword that are currently in use.
      * @param keyword one of the keywords returned by getKeywords.
      * @see #getKeywords
-     * @draft ICU 3.0
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.0
      */
     public static final String[] getKeywordValues(String keyword) {
         if (!keyword.equals(KEYWORDS[0])) {
@@ -634,19 +624,17 @@ public abstract class Collator implements Comparator, Cloneable
      * applications who wish to cache collators, or otherwise reuse
      * collators when possible.  The functional equivalent may change
      * over time.  For more information, please see the <a
-     * href="http://icu.sourceforge.net/userguide/locale.html#services">
+     * href="http://www.icu-project.org/userguide/locale.html#services">
      * Locales and Services</a> section of the ICU User Guide.
      * @param keyword a particular keyword as enumerated by
      * getKeywords.
      * @param locID The requested locale
      * @param isAvailable If non-null, isAvailable[0] will receive and
      * output boolean that indicates whether the requested locale was
-     * 'available' to the collation service. The locale is defined as
-     * 'available' if it physically exists within the collation locale
-     * data.  If non-null, isAvailable must have length >= 1.
+     * 'available' to the collation service. If non-null, isAvailable 
+     * must have length >= 1.
      * @return the locale
-     * @draft ICU 3.0
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.0
      */
     public static final ULocale getFunctionalEquivalent(String keyword,
                                                         ULocale locID,
@@ -664,8 +652,7 @@ public abstract class Collator implements Comparator, Cloneable
      * @param locID The requested locale
      * @return the locale
      * @see #getFunctionalEquivalent(String,ULocale,boolean[])
-     * @draft ICU 3.0
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.0
      */
     public static final ULocale getFunctionalEquivalent(String keyword,
                                                         ULocale locID) {
@@ -689,8 +676,7 @@ public abstract class Collator implements Comparator, Cloneable
      * @param objectLocale the locale of the collator
      * @param displayLocale the locale for the collator's display name
      * @return the display name
-     * @draft ICU 3.2
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.2
      */
     static public String getDisplayName(ULocale objectLocale, ULocale displayLocale) {
         return getShim().getDisplayName(objectLocale, displayLocale);
@@ -710,8 +696,7 @@ public abstract class Collator implements Comparator, Cloneable
      * Get the name of the collator for the objectLocale, localized for the current locale.
      * @param objectLocale the locale of the collator
      * @return the display name
-     * @draft ICU 3.2
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 3.2
      */
     static public String getDisplayName(ULocale objectLocale) {
         return getShim().getDisplayName(objectLocale, ULocale.getDefault());
